#ifndef AKENTI_INIT_HPP
#define AKENTI_INIT_HPP

#include <string>

using std::string;

namespace Akenti {

/**
  * This class provides static methods to configure the akenti system.
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */
class AkentiInit {

public:

  /**
    * Loads the system <i>Properties</i>.
    * Installs a security provider if it has not already be installed. <BR>
    * Loads the server's credentials if securiry is <i>on</i>.         <BR>
    * Sets the external cache if caching is <i>on</i>.                 <BR>
    * Loads the resource/policy mappings.                              <BR>
    * 
    * @param confFile string the pathname of the Akenti configuration file
    * @param message string out parameter to store the status of this call
    * @return true if successful false otherwise
    *
    * @see init(string&)
    */
  static bool init(const string& confFile, string& message);

  /**
    * Installs a security provider if it has not already be installed. <BR>
    * Loads the server's credentials if securiry is <i>on</i>.         <BR>
    * Sets the external cache if caching is <i>on</i>.                 <BR>
    * Loads the resource/policy mappings.                              <BR>
    *
    * This call assumes that the system properties have already been loaded.
    *
    * @param message string out parameter to store the status of this call
    * @return true if successful false otherwise
    *
    * @see Provider
    * @see ServerContext
    * @see ExternalCache
    */
  static bool init(string& message);

private:

  /**
    * Disallow construction of this object.
    */
  AkentiInit();

};

} // end of name space

#endif
