#ifndef AKENTI_MESSAGE
#define AKENTI_MESSAGE
#include <string>
#include "Xerces-Decls.hpp"

using std::string;

namespace Akenti {


/**
  * <pre>
  * 100-199 Ok messages
  *
  * 200-249 Problems that the client finds : cannot connect to server
  * 
  * 250-299 Problems that server finds: wrong request, bad credential
  *         - user needs to fix something
  * 300-399 Permission denied - errors from the Authorizer   
  *         - maps to user as permission denied, 
  * 400-499 Problems in policy collection and verififcation  
  * 500-599 Problems in UseCondition collection and verification
  *         - both map to user as policy is inconsistant
  * 900-999 Programming errors exceptions and errors caught
  *         - maps to user as code is wrong
  * </pre> 
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */
class AkentiMessage {
   
public:

  /**
   * constructor -creates null message
    */
  AkentiMessage();

  /**
   * constructor -sets code
    */
  AkentiMessage(int code);

  /**
     constructor - sets code and message
    */
  AkentiMessage(int code , const string& message);
  
  /**
     destructor
    */
  ~AkentiMessage();

  /**
    * Returns the code .
    */
  int getCode() const;

  /**
    * Returns the message.
    */
  const string& getMessage() const;

  /**
    * Returns the concatenation of the code and the message.
    */
  string toString() const;

  /**
   */
  void toXML(DOMElement* mesg) const;

  /**
   */
  void fromXML(const DOMElement* mesg);

  bool operator==(const AkentiMessage& am) const;

private:
  
  int code;

  string message;

};

};

#endif
