#ifndef AK_CERTIFICATE_HPP
#define AK_CERTIFICATE_HPP
#include "ref_ptr.hpp"
#include "CertificateImpl.hpp"

/**
  * A <i>Certificate<i> object is a <i>reference-count</i> pointer
  * that wraps a <i>CertificateImpl</i> object. It provides applications,
  * albeit indirectly,  the  services that a certificate supports. 
  *
  * @see ref_ptr
  * @see CertificateImpl
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

namespace Akenti {

class Certificate : public ref_ptr<CertificateImpl> {

public:

  /**
    * Constructs a <i>Certificate</i> given a <i>CertificateImpl</i>
    * object.
    *
    * @param impl  wrapped <i>CertificateImpl</i> object
    * @see ref_ptr
    * @see CertificateImpl
    */
  Certificate(CertificateImpl *impl = NULL) : ref_ptr<CertificateImpl> (impl) { 
  }

  /**
    * Decrements the count of references to the wrapped <i>CertificateImpl</i>
    * object. If this count is zero, then the wrapped object is deleted.
    *
    * @see ref_ptr
    */
  ~Certificate() {
  }

};

} // end of namespace Akenti

#endif
