#ifndef AK_CERTIFICATE_CHAIN_HPP
#define AK_CERTIFICATE_CHAIN_HPP

#include "ref_ptr.hpp"
#include "CertificateChainImpl.hpp"

/**
  * A <i>CertificateChain<i> object is a <i>reference-count</i> pointer
  * that wraps a <i>CertificateChainImpl</i> object. It provides applications,
  * albeit indirectly,  the  services that a certificate chain supports. 
  *
  * @see ref_ptr
  * @see CertificateChainImpl
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

namespace Akenti {

class CertificateChain : public ref_ptr<CertificateChainImpl> {

public:

  /**
    * Constructs a <i>CertificateChain</i> given a <i>CertificateChainImpl</i>
    * object.
    *
    * @param impl  wrapped <i>CertificateChainImpl</i> object
    * @see ref_ptr
    * @see CertificateChainImpl
    */
  CertificateChain(CertificateChainImpl *impl = NULL) : ref_ptr<CertificateChainImpl> (impl) { 
  }

  /**
    * Decrements the count of references to the wrapped <i>CertificateChainImpl</i>
    * object. If this count is zero, then the wrapped object is deleted.
    *
    * @see ref_ptr
    */
  ~CertificateChain() {
  }

};

} // end of namespace Akenti

#endif
