#ifndef AK_FILTER_HPP
#define AK_FILTER_HPP

#include <string>

using std::string;

/**
  * A <i>Filter<i> is the base class for filter functions. A concrete filter
  * class must provide an accept method that compares a given string 
  * against a string pattern to see if it matches. Examples of patterns are
  * <pre>
  * "*.pem" matches any filename that ends with the extension pem
  * "*.*" matches any two component file name
  * "*" matches any name
  * </pre>
  *
  * @version 1.1 00/11/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

namespace Akenti {

class Filter {

public:

  /**
    * Destructor.
    */
  virtual ~Filter() {
  }

  /**
    * Determines if the filename matches the filter's pattern.
    *
    * @param filename string name to be matched.
    * @return bool true if filename matches the filter pattern, otherwise false.
    */
  virtual bool accept(const string& filename) const {
    return true;
  }

};

} // end of namespace Akenti

#endif
