#ifndef CERT_INFO_COLLECTOR_HPP
#define CERT_INFO_COLLECTOR_HPP

#include "CertInfo.hpp"

namespace Akenti {

/**
  * The <i>CertInfoCollector</I> contains all the certificates collected 
  * in the process of trying to determine if a request can be
  * satisfied.
  * 
  * @see AkentiMessage 
  * 
  * @version 1.0 04/05/20
  * @author Sushila R. Subramanian
  **/

class CertInfoCollector {
  
public:

  CertInfoCollector();
   
  /**
    * Destroys this object
    */
  ~CertInfoCollector();

  /**
    * Adds a <i>CertInfo</i> object (containing a certificate)
    * to the vector.
    */
  void addCertInfo (const CertInfo& certinfo);

  /**
    * Returns the vector of <i>CertInfo</i> objects
    * @see CertInfo
    */

  const vector <CertInfo>& getCertInfoVec();

  /**
    * Sets the vector of <i>CertInfo</i> objects 
    * @see CertInfo
    */

  void setCertInfoVec(const vector <CertInfo>& certInfoVec);

  /**
    * Adds an <i>AkentiMessage</i> to the <i>CertInfo</i> object at index
    * <i>index</i> within the vector.
    * 
    * @see AkentiMessage
    */
  void addMessage (int index, AkentiMessage mesg);
  
  /**
    * Sets the "used" value in the <i>CertInfo</i> object at index
    * <i>index</i> within the vector.
    * 
    */
  void setUsed (int index, bool usedVal);
  
  /**
    * Sets the "error" value in the <i>CertInfo</i> object at index
    * <i>index</i> within the vector.
    * 
    */
  void setError (int index, bool err);
  
  /**
    * Returns the <i>CertInfo</i> object at index <i>index</i> within the vector
    *
    * @see CertInfo
    */
  CertInfo &getCertInfo (int index);
  
  /**
    * Reorders the vector of <i>CertInfo</i> objects, so that a Policy
    * Certificate and its associated Use Condition certificates are listed
    * in order together.
    *
    * @see CertInfo
    */

  void reorderCertInfoVec ();

  /**
    * For debugging - not written yet
    */
  //string paramString() const;

  /**
    * Returns/creates a new instance of <i>CertInfoCollector</i>
    */
  static CertInfoCollector* createCertInfoCollector();
  
  /**
    * Sets the status of the collection so far. 
    */
  void setStatus (bool errorVal);

  /**
    * Returns the status of the collection so far.
    */
  bool getStatus ();

  /**
    * Return index of CertInfo in the vector if the hashcode exists for 
    * a <i>Policy</i> or <i>Use Condition</i> certificate
    * Return -1 if it doesnt exist
    */
  int lookup (string hcode, string type); 

  /**
    * Return index of CertInfo in the vector if the hashcode exists for 
    * a <i>Policy</i> or <i>Use Condition</i> certificate
    * Return -1 if it doesnt exist
    */
  int lookup (string hcode, string type, string  uid); 

private:

  vector<CertInfo> certInfoList;
  bool  didItWork;

};

}  // end of namesapce

#endif  /* CERT_INFO_COLLECTOR_HPP */
